==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/l3vpnsvc/DefaultVpnServices.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.vpnservices.VpnSvc;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnServices.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnServices extends InnerModelObject implements VpnServices {
    protected List<VpnSvc> vpnSvc;

    @Override
    public List<VpnSvc> vpnSvc() {
        return vpnSvc;
    }

    @Override
    public void vpnSvc(List<VpnSvc> vpnSvc) {
        this.vpnSvc = vpnSvc;
    }

    @Override
    public void addToVpnSvc(VpnSvc addTo) {
        if (vpnSvc == null) {
            vpnSvc = new ArrayList<>();
        }
        vpnSvc.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(vpnSvc);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnServices) {
            DefaultVpnServices other = (DefaultVpnServices) obj;
            return
                Objects.equals(vpnSvc, other.vpnSvc);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnSvc=" + vpnSvc)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnServices.
     */
    public DefaultVpnServices() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/l3vpnsvc/DefaultVpnServices.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.l3vpnsvc.vpnservices.VpnSvc;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of vpnServices.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultVpnServices extends InnerModelObject implements VpnServices {
    protected List<VpnSvc> vpnSvc;

    @Override
    public List<VpnSvc> vpnSvc() {
        return vpnSvc;
    }

    @Override
    public void vpnSvc(List<VpnSvc> vpnSvc) {
        this.vpnSvc = vpnSvc;
    }

    @Override
    public void addToVpnSvc(VpnSvc addTo) {
        if (vpnSvc == null) {
            vpnSvc = new ArrayList<>();
        }
        vpnSvc.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(vpnSvc);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultVpnServices) {
            DefaultVpnServices other = (DefaultVpnServices) obj;
            return
                Objects.deepEquals(vpnSvc, other.vpnSvc);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("vpnSvc=" + vpnSvc)
            .toString();
    }


    /**
     * Creates an instance of defaultVpnServices.
     */
    public DefaultVpnServices() {
    }

}
